package com.ademicon.controller;

import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import com.ademicon.model.ContratoResponse;
import com.ademicon.service.ContratoService;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fluig.sdk.api.common.SDKException;

@Path("/contrato")
public class ContratoController {

    private static ContratoService contratoService = new ContratoService();

    @GET
    @Path("/")
    @Produces(MediaType.APPLICATION_JSON)
    @Consumes(MediaType.APPLICATION_JSON)
    public Response doGet() throws SDKException {
        return Response.ok("{user:ok}").build();
    }

    @POST
    @Path("/error")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response doError(String contrato) {
        try {
            String resposta = "{\"status\":\"BAD_REQUEST\",\"errors\":[\"cnpjAgenteFinanceiro: size must be between 14 and 14\",\"cpfCnpjDevedorFinanciado: size must be between 11 and 14\",\"veiculos[0].numeroGravame: size must be between 8 and 8\",\"siglaIndiceFinaceiro: valor inválido. Valores válidos: PREFIXADO, POSFIXADO, VALORBEM, IGP, IGPM, IPC, OUTRO\",\"cnpjAgenteFinanceiro: CNPJ inválido ou não credenciado\",\"veiculos[0].identificadorRemarcacao: deve ser 1 ou 2\"],\"message\":\"Validation failed.\",\"code\":400}";

            ObjectMapper mapper = new ObjectMapper();
            var a = mapper.readTree(resposta);

            return Response.status(Status.BAD_REQUEST).entity(a).build();
        } catch (Exception e) {
            System.out.println("ERRO API PLACETI CONTROLLER DOERROR");
            return Response.status(Status.INTERNAL_SERVER_ERROR).entity(e).build();
        }

    }

    @POST
    @Path("/sucess")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response doSucces(String contrato) {
        try {
            String resposta = "[{\"chassi\":\"98N5X6ttm07f46786\",\"cnpjAgente\":\"84911098000129\",\"codResposta\":\"0\",\"codRespostaDetran\":\"0\",\"hashOperacao\":\"<string>\",\"msgResposta\":\"Ok\",\"msgRespostaDetran\":\"NoOK\",\"numeroRegistroEletronico\":\"20240000143797\",\"operacao\":\"<string>\"}]";
            ObjectMapper mapper = new ObjectMapper();

            List<ContratoResponse> list = mapper.readValue(resposta, new TypeReference<List<ContratoResponse>>() {
            });

            return Response.status(Status.CREATED).entity(list).build();

        } catch (Exception e) {
            System.out.println("ERRO API PLACETI CONTROLLER DOSUCESS");
            return Response.status(Status.INTERNAL_SERVER_ERROR).entity(e).build();
        }
    }

    @POST
    @Path("/incluir")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response doPost(String contrato) throws Exception {

        try {
            System.out.println("Chegou na API");
            System.out.println(contrato);
            Response contratoModel = contratoService.incluir(contrato);
            System.out.println("PASSOU SERVIÇO");

            return Response.status(contratoModel.getStatus()).entity(contratoModel.getEntity()).build();

        } catch (Exception e) {
            System.out.println("ERRO API");
            System.out.println(e);
            return Response.status(Status.INTERNAL_SERVER_ERROR).build();
        }
    }

    @PUT
    @Path("/upload/numeroRegistroEletronico/{numeroRegistroEletronico}")
    @Consumes(MediaType.APPLICATION_JSON)
    @Produces(MediaType.APPLICATION_JSON)
    public Response doUpload(@PathParam(value = "numeroRegistroEletronico") String numeroRegistroEletronico,
            String arquivo) throws Exception {
        try {

            System.out.println("RECEBIMENTO DE CONTRATO");
            System.out.println(numeroRegistroEletronico);
            System.out.println(arquivo);

            Response contratoResponse = contratoService.upload(numeroRegistroEletronico, arquivo);
            return Response.status(contratoResponse.getStatus()).entity(contratoResponse.getEntity()).build();
            // return Response.status(Status.OK).entity("{\"status\":\"ok\"}").build();

        } catch (Exception e) {
            System.out.println("FALHA RECEBIMENTO DE CONTRATO");
            System.out.println(e);
            return Response.status(Status.INTERNAL_SERVER_ERROR).build();

        }
    }

}
